@@ -23,21 +23,37 @@ get_result <- function(output, options) {
   ## Timeout?
   if (output$timeout) stop(make_error(output))
 
-  ## No output file and no error file? Some other (system?) error then
+  ## No output file and no error file? Some other (system?) error then,
+  ## unless exit status was zero, which is probably just quit().
+  ## (Newer R versions do not write a corrupt RDS file in this case.)
+  ret <- NULL
   errorres <- paste0(res, ".error")
-  killmsg <- "could not start R, or it has crashed or was killed"
+  killmsg <- paste(
+    "could not start R, exited with non-zero status,",
+    "has crashed or was killed")
   if (! file.exists(res) && ! file.exists(errorres)) {
-    stop(make_error(output, killmsg))
+    if (is.na(output$status) || output$status != 0) {
+      stop(make_error(output, killmsg))
+    } else  {
+      return(ret)
+    }
   }
 
   ## No error file? Then probably all is well, return the output
   ## If this is currupt, then the R process has crashed
   ## This cannot happen from R 3.5.0, because that version only writes
   ## out the output file if no error or crash has happened.
+  ## (Older R versions write a corrupt RDS file in this case.)
   if (! file.exists(errorres)) {
     tryCatch(
       ret <- readRDS(res),
-      error = function(e) stop(make_error(output, killmsg)))
+      error = function(e) {
+        if (is.na(output$status) || output$status != 0) {
+          stop(make_error(output, killmsg))
+        }
+      }
+    )
+
     return(ret)
   }
 
