@@ -27,8 +27,6 @@ with_envvar <- function(new, code) {
 
 os_platform <- function() .Platform$OS.type
 
-try_silently <- function(expr) try(expr, silent = TRUE)
-
 enumerate <- function(x) {
   if (length(x) == 0) {
     ""
@@ -40,22 +38,6 @@ enumerate <- function(x) {
   }
 }
 
-strrep <- function(x, times) {
-  x <- as.character(x)
-  if (length(x) == 0L) return(x)
-  r <- .mapply(
-    function(x, times) {
-      if (is.na(x) || is.na(times)) return(NA_character_)
-      if (times <= 0L) return("")
-      paste0(replicate(times, x), collapse = "")
-    },
-    list(x = x, times = times),
-    MoreArgs = list()
-  )
-
-  unlist(r, use.names = FALSE)
-}
-
 ## Thanks to Romain for the idea!
 ## https://github.com/romainfrancois/trump/blob/
 ## 7845b83343afa356e4259c054e7c9a910034f170/R/trump.R
@@ -63,3 +45,13 @@ strrep <- function(x, times) {
 crash <- function() {
   get("attach")( structure(list(), class = "UserDefinedDatabase")  )
 }
+
+is_flag <- function(x) {
+  is.logical(x) && length(x) == 1 && !is.na(x)
+}
+
+is_string <- function(x) {
+  is.character(x) &&
+  length(x) == 1 &&
+  !is.na(x)
+}
